@@ -38,6 +38,7 @@ class Completion:
             openai.api_key = openai_proxy.api_key
             response = openai.Completion.create(**params)
             response["price"] = token_estimator.price_calculator_completion(params)
+            openai_proxy.session_price += response["price"]
             return response
 
         params["username"] = openai_proxy.username
@@ -47,6 +48,7 @@ class Completion:
         r = requests.post('http://openai-proxy.herokuapp.com/b/request/openai/completion', json=params)
         response = json.loads(r.text)
         if response['status'] == 'success':
+            openai_proxy.session_price += response['response']["price"]
             return response['response']
         else:
             return response
